@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2001 Erez Zadok
+ * Copyright (c) 1997-2002 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: amfs_auto.c,v 1.9.2.7 2001/04/14 21:08:19 ezk Exp $
+ * $Id: amfs_auto.c,v 1.9.2.9 2002/01/21 00:49:35 ezk Exp $
  *
  */
 
@@ -434,7 +434,7 @@ try_mount(voidp mvp)
 #ifdef DEBUG
   if (error > 0) {
     errno = error;
-    dlog("amfs_auto call to mount_node failed: %m");
+    dlog("amfs_auto: call to mount_node(%s) failed: %m", mp->am_path);
   }
 #endif /* DEBUG */
 
