@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2001 Erez Zadok
+ * Copyright (c) 1997-2002 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: mount_linux.c,v 1.11.2.11 2001/05/20 03:33:42 ezk Exp $
+ * $Id: mount_linux.c,v 1.11.2.15 2002/06/21 18:32:07 ezk Exp $
  */
 
 /*
@@ -68,7 +68,6 @@ const struct opt_map opt_map[] =
   {MNTTAB_OPT_SUID,	1,	MNT2_GEN_OPT_NOSUID},
   {MNTTAB_OPT_NOSUID,	0,	MNT2_GEN_OPT_NOSUID},
 #ifdef MNT2_GEN_OPT_NODEV
-  {MNTTAB_OPT_DEV,	1,	MNT2_GEN_OPT_NODEV},
   {MNTTAB_OPT_NODEV,	0,	MNT2_GEN_OPT_NODEV},
 #endif /* MNT2_GEN_OPT_NODEV */
 #ifdef MNT2_GEN_OPT_SYNC
@@ -239,8 +238,13 @@ mount_linux(MTYPE_TYPE type, mntent_t *mnt, int flags, caddr_t data)
   if (STREQ(type, MOUNT_TYPE_NFS)) {
     /* Fake some values for linux */
     mnt_data->version = NFS_MOUNT_VERSION;
-    if (!mnt_data->timeo)
+    if (!mnt_data->timeo) {
       mnt_data->timeo = 7;
+#ifdef MNT2_NFS_OPT_TCP
+      if (mnt_data->flags & MNT2_NFS_OPT_TCP)
+	mnt_data->timeo = 600;
+#endif
+    }
     if (!mnt_data->retrans)
       mnt_data->retrans = 3;
 
@@ -270,15 +274,15 @@ mount_linux(MTYPE_TYPE type, mntent_t *mnt, int flags, caddr_t data)
 #endif /* MNT2_NFS_OPT_VER3 */
       memcpy(mnt_data->old_root.data, mnt_data->root.data, FHSIZE);
 
-#ifdef HAVE_FIELD_NFS_ARGS_T_BSIZE
+#ifdef HAVE_NFS_ARGS_T_BSIZE
     /* linux mount version 3 */
     mnt_data->bsize = 0;	/* let the kernel decide */
-#endif /* HAVE_FIELD_NFS_ARGS_T_BSIZE */
+#endif /* HAVE_NFS_ARGS_T_BSIZE */
 
-#ifdef HAVE_FIELD_NFS_ARGS_T_NAMLEN
+#ifdef HAVE_NFS_ARGS_T_NAMLEN
     /* linux mount version 2 */
     mnt_data->namlen = NAME_MAX;	/* 256 bytes */
-#endif /* HAVE_FIELD_NFS_ARGS_T_NAMELEN */
+#endif /* HAVE_NFS_ARGS_T_NAMELEN */
 
     mnt_data->fd = socket(AF_INET, SOCK_DGRAM, IPPROTO_UDP);
     if (mnt_data->fd < 0) {
