@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2001 Erez Zadok
+ * Copyright (c) 1997-2002 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: mount_svr4.c,v 1.4.2.1 2001/01/10 03:23:18 ezk Exp $
+ * $Id: mount_svr4.c,v 1.4.2.3 2002/02/12 02:44:18 ib42 Exp $
  *
  */
 
@@ -145,13 +145,5 @@ mount_svr4(char *fsname, char *dir, int flags, MTYPE_TYPE type, caddr_t data, co
 # endif /* defined(MOUNT_TYPE_CACHEFS) && defined(MNTTAB_TYPE_CACHEFS) */
 #endif /*HAVE_FS_CACHEFS */
 
-#ifdef HAVE_FS_AUTOFS
-# if defined(MOUNT_TYPE_AUTOFS) && defined(MNTTAB_TYPE_AUTOFS)
-  if (STREQ(type, MOUNT_TYPE_AUTOFS))
-    return sys_mount(fsname, dir, (MNT2_GEN_OPT_DATA | flags),
-		     type, (char *) data, sizeof(autofs_args_t));
-# endif /* defined(MOUNT_TYPE_AUTOFS) && defined(MNTTAB_TYPE_AUTOFS) */
-#endif /* HAVE_FS_AUTOFS */
-
   return EINVAL;
 }
