@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2001 Erez Zadok
+ * Copyright (c) 1997-2002 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: mtab_mach3.c,v 1.4.2.1 2001/01/10 03:23:19 ezk Exp $
+ * $Id: mtab_mach3.c,v 1.4.2.4 2002/01/21 00:49:47 ezk Exp $
  *
  */
 
@@ -323,10 +323,16 @@ rewrite_mtab(mntlist *mp, const char *mnttabname)
     tmpname[1] = '\0';
   }
   strcat(tmpname, "/mtabXXXXXX");
-  mktemp(tmpname);
   retries = 0;
 enfile1:
-  if ((tmpfd = open(tmpname, O_RDWR | O_CREAT | O_TRUNC, 0644)) < 0) {
+#ifdef HAVE_MKSTEMP
+  tmpfd = mkstemp(tmpname);
+  fchmod(tmpfd, 0644);
+#else /* not HAVE_MKSTEMP */
+  mktemp(tmpname);
+  tmpfd = open(tmpname, O_RDWR | O_CREAT | O_TRUNC, 0644);
+#endif /* not HAVE_MKSTEMP */
+  if (tmpfd < 0) {
     if (errno == ENFILE && retries++ < NFILE_RETRIES) {
       sleep(1);
       goto enfile1;
