@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2001 Erez Zadok
+ * Copyright (c) 1997-2002 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: nfs_prot_aix4_3.h,v 1.3.2.2 2001/01/10 03:23:21 ezk Exp $
+ * $Id: nfs_prot_aix4_3.h,v 1.3.2.5 2002/06/21 22:40:46 ib42 Exp $
  *
  */
 
@@ -256,6 +256,35 @@ struct aix42_nfs_args {
   struct pathcnf *pathconf;	/* pathconf */
 };
 
+/*
+ * IBM is in dire need of taking a soft-eng class.
+ * They changed the API/ABI (namely the nfs3_args structure)
+ * in a service pack...
+ *
+ * All the following *_bis junk is here to try and deal with this idiocy.
+ */
+#define MOUNT_TYPE_NFS3_BIS 0x12344321
+struct aix42_nfs_args_bis {
+  struct sockaddr_in addr;	/* server address and port */
+  caddr_t u0;			/* ??? UNKNOWN ??? */
+  unsigned long proto;		/* IPPROTO_TCP/IPPROTO_UDP */
+  char *hostname;		/* pointer to hostname? */
+  char *netname;		/* pointer to netname? */
+  caddr_t fh;			/* pointer to NFS v3 fh? */
+  unsigned long junk;		/* IBM sux, IBM sux, IBM sux... */
+  unsigned long flags;		/* flags */
+  unsigned long wsize;		/* wsize */
+  unsigned long rsize;		/* rsize */
+  unsigned long timeo;		/* timeo */
+  unsigned long retrans;	/* retrans */
+  unsigned long acregmin;	/* acregmin */
+  unsigned long acregmax;	/* acregmax */
+  unsigned long acdirmin;	/* acdirmin */
+  unsigned long acdirmax;	/* acdirmax */
+  unsigned long u14;		/* ??? UNKNOWN ??? */
+  struct pathcnf *pathconf;	/* pathconf */
+};
+
 typedef struct {
   u_int fhandle3_len;
   char *fhandle3_val;
@@ -305,19 +334,6 @@ typedef struct nfs_fh3 nfs_fh3;
 
 #endif /* MNT_NFS3 */
 
-/*
- **************************************************************************
- * AIX 4.3's autofs is not ported or tested yet...
- * For now, undefine it or define dummy entries.
- **************************************************************************
- */
-#ifdef MNT_AUTOFS
-# undef MNT_AUTOFS
-#endif /* MNT_AUTOFS */
-#ifdef HAVE_FS_AUTOFS
-# undef HAVE_FS_AUTOFS
-#endif /* HAVE_FS_AUTOFS */
-
 /*
  * EXTERNALS:
  */
