@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2001 Erez Zadok
+ * Copyright (c) 1997-2002 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: nfs_prot_irix6.h,v 1.4.2.4 2001/01/12 23:28:59 ro Exp $
+ * $Id: nfs_prot_irix6.h,v 1.4.2.6 2002/02/12 02:44:19 ib42 Exp $
  *
  */
 
@@ -497,22 +497,4 @@ extern bool_t xdr_mountres3(XDR *, mountres3 *);
 extern bool_t xdr_fhstatus(XDR *, struct fhstatus *);
 extern bool_t xdr_mountlist(XDR *, struct mountlist **);
 
-
-/*
- **************************************************************************
- * Irix 6's autofs is not ported or tested yet...
- * For now, undefine it or define dummy entries.
- **************************************************************************
- */
-#ifdef MNTTYPE_AUTOFS
-# undef MNTTYPE_AUTOFS
-#endif /* MNTTYPE_AUTOFS */
-#ifdef MNTTAB_TYPE_AUTOFS
-# undef MNTTAB_TYPE_AUTOFS
-#endif /* MNTTAB_TYPE_AUTOFS */
-#ifdef HAVE_FS_AUTOFS
-# undef HAVE_FS_AUTOFS
-#endif /* HAVE_FS_AUTOFS */
-
-
 #endif /* not _AMU_NFS_PROT_H */
