@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2001 Erez Zadok
+ * Copyright (c) 1997-2002 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: nfs_prot_linux.h,v 1.5.2.5 2001/03/15 08:32:44 ib42 Exp $
+ * $Id: nfs_prot_linux.h,v 1.5.2.8 2002/02/12 02:44:19 ib42 Exp $
  *
  */
 
@@ -56,6 +56,9 @@
  * name.
  */
 #include <linux/version.h>
+#ifndef KERNEL_VERSION
+# define KERNEL_VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))
+#endif /* not KERNEL_VERSION */
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
 # ifndef MS_BIND
 #  define MS_BIND 4096
@@ -209,37 +212,11 @@ typedef statfsres	nfsstatfsres;
 typedef symlinkargs	nfssymlinkargs;
 typedef writeargs	nfswriteargs;
 
-
-/*
- * AUTOFS definitions (missing on linux):
- */
-
-#define	AUTOFS_PROG ((unsigned long)(100099))
-#define	AUTOFS_VERS ((unsigned long)(1))
-#define	AUTOFS_MOUNT ((unsigned long)(1))
-#define	AUTOFS_UNMOUNT ((unsigned long)(2))
-#define	A_MAXNAME 255
-#define	A_MAXOPTS 255
-#define	A_MAXPATH 1024
-
 typedef struct mntrequest mntrequest;
 typedef struct mntres mntres;
 typedef struct umntrequest umntrequest;
 typedef struct umntres umntres;
-typedef struct auto_args autofs_args_t;
 
-struct auto_args {
-#if 0
-  struct netbuf	addr;		/* daemon address */
-#endif
-  char		*path;		/* autofs mountpoint */
-  char		*opts;		/* default mount options */
-  char		*map;		/* name of map */
-  int		mount_to;	/* time in sec the fs is to remain */
-				/* mounted after last reference */
-  int 		rpc_to;		/* timeout for rpc calls */
-  int		direct;		/* 1 = direct mount */
-};
 
 /*
  * We use our own definitions here, because the definitions in the
