@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2001 Erez Zadok
+ * Copyright (c) 1997-2002 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: nfs_prot_sunos5_8.h,v 1.2.2.1 2001/01/10 03:23:26 ezk Exp $
+ * $Id: nfs_prot_sunos5_8.h,v 1.2.2.3 2002/02/12 02:44:19 ib42 Exp $
  *
  */
 
@@ -385,21 +385,4 @@ struct statfsres {
   } sfr_u;
 };
 
-
-/*
- **************************************************************************
- * Solaris 2.6/7/8 changed autofs a lot.  A re-port to am-utils is required.
- * For now, undefine it or define dummy entries.
- **************************************************************************
- */
-#ifdef MNTTYPE_AUTOFS
-# undef MNTTYPE_AUTOFS
-#endif /* MNTTYPE_AUTOFS */
-#ifdef MNTTAB_TYPE_AUTOFS
-# undef MNTTAB_TYPE_AUTOFS
-#endif /* MNTTAB_TYPE_AUTOFS */
-#ifdef HAVE_FS_AUTOFS
-# undef HAVE_FS_AUTOFS
-#endif /* HAVE_FS_AUTOFS */
-
 #endif /* not _AMU_NFS_PROT_H */
